@@ -1,5 +1,4 @@
 ### R code from vignette source 'twoACexamples.Rnw'
-### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: Initialize
@@ -318,3 +317,11 @@ text(2, 0.6, "95th percentile consumer")
 sessionInfo()
 
 
+###################################################
+### code chunk number 33: Finalize
+###################################################
+
+options(op)
+
+
+
